@@ -118,11 +118,14 @@ void RdpView::startQuitting()
         return; // ignore repeated triggers
     }
 
-    unpressModifiers();
-
     qCDebug(KRDC) << "Stopping RDP session";
     m_quitting = true;
-    m_session->stop();
+
+    unpressModifiers();
+
+    if (m_session) {
+        m_session->stop();
+    }
 
     qCDebug(KRDC) << "RDP session stopped";
     Q_EMIT disconnected();
@@ -169,7 +172,8 @@ bool RdpView::start()
             setStatus(Connected);
             break;
         case RdpSession::State::Closed:
-            startQuitting();
+            Q_EMIT disconnected();
+            setStatus(Disconnected);
             break;
         default:
             break;
@@ -337,7 +341,6 @@ void RdpView::handleError(const unsigned int error)
     case FREERDP_ERROR_RPC_INITIATED_DISCONNECT_BY_USER:
     case FREERDP_ERROR_LOGOFF_BY_USER:
         // user or admin initiated action, quit without error
-        startQuitting();
         return;
     case FREERDP_ERROR_DISCONNECTED_BY_OTHER_CONNECTION:
         title = i18nc("@title:dialog", "Connection Closed");
@@ -357,9 +360,6 @@ void RdpView::handleError(const unsigned int error)
     qCDebug(KRDC) << "error message" << title << message;
     // TODO offer reconnect if approriate
     KMessageBox::error(this, message, title);
-
-    // FIXME are there any situations we don't want to quit?
-    startQuitting();
 }
 
 void RdpView::onLogonError(const QString &error)
